BOOST_PP_VARIADICS

The BOOST_PP_VARIADICS macro specifies whether variadic macro support exists.

#### Usage

BOOST_PP_VARIADICS
Remarks
The macro is an object-like macro. It is used in internal code to check for the presence of variadic macro support. It can be used by the end-user for the same purpose. The macro equals 1 if variadic macros are supported and 0 if they are not.
Requirements
Header: <boost/preprocessor/config/variadics.hpp>

#### Sample Code

    #include <boost/preprocessor/config/variadics.hpp>

    #if BOOST_PP_VARIADICS
    #define SOME_MACRO(...) // replacement list
    #else
    #define SOME_MACRO(param1,param2) // replacement list
    #endif

© Copyright Edward Diener 2011

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)